%
% Berechnung von Bandstrukturen in einer Dimension
%
% Andreas Buhr, 11. 08. 2006
%
% In einer Dimension in einem periodischen
% Potential kann der Hamiltonoperator im 
% Impulsraum sehr einfach in einer Matrix
% dargestellt werden. 
% Die Energie ist der Eigenwert dieser Matrix.
% 
% Dieses einfache Skript rechnet die Energiebaender
% fuer einen eindimensionalen Kristall aus.
%

clear all;

%allgemeine Groessen:

%h-quer:
hbar = 1.0545716e-34;
%Elektronenmasse:
melec = 9.10938188e-31;
%ein Angstrom:
AA = 1e-10;


%spezifische Groessen:

%Gitterabstand
a = AA;
%Vektor des reziproken Gitters:
K = 2*pi/a;

%Energie eines Elektrons auf der Bragg-Ebene:
e_bragg = hbar^2*(K/2)^2/(2*melec);

% %schwaches periodisches Potential:
U_1 = 1/6*e_bragg;
U_2 = 1/8*e_bragg;
U_3 = 1/12*e_bragg;
U_4 = 1/18*e_bragg;

%Rechenbereich
kmax = 4;
bereich = [-kmax:1:kmax];

resultvec = [];
for mult = -0.5:0.01:0.5
    %k-Vektor in der ersten Brillouin-Zone:
    k = mult*K;
    
    hauptdiagonale = hbar^2*(k+(K*bereich)).^2/(2*melec);
    rechenmatrix = diag(hauptdiagonale,0) ...
        + diag(U_1*ones(2*kmax,1),1) + diag(U_1*ones(2*kmax,1),-1)...
        + diag(U_2*ones(2*kmax-1,1),2) + diag(U_1*ones(2*kmax-1,1),-2)...
        + diag(U_3*ones(2*kmax-2,1),3) + diag(U_1*ones(2*kmax-2,1),-3)...
        + diag(U_4*ones(2*kmax-3,1),4) + diag(U_1*ones(2*kmax-3,1),-4);
    
    
    [V,D] = eig(rechenmatrix);
    D = sort(diag(D));
    resultvec = [resultvec D];
    mult
end    
hold on
for i = 1:3
    plot(resultvec(i,:));
end
hold off
